@@ -247,7 +247,7 @@ fn build<D>(
                     visibility: wgpu::ShaderStages::FRAGMENT,
                     ty: wgpu::BindingType::Texture {
                         sample_type: wgpu::TextureSampleType::Float {
-                            filterable: false,
+                            filterable: true,
                         },
                         view_dimension: wgpu::TextureViewDimension::D2,
                         multisampled: false,
@@ -308,6 +308,7 @@ fn build<D>(
         primitive: wgpu::PrimitiveState {
             topology: wgpu::PrimitiveTopology::TriangleStrip,
             front_face: wgpu::FrontFace::Cw,
+            strip_index_format: Some(wgpu::IndexFormat::Uint16),
             ..Default::default()
         },
         depth_stencil,
